==> gnue-common_0.5.4.1.orig.tar.gz: gnue-common-0.5.4.1/src/datasources/drivers/odbc/wodbc/Info.py <==
#
# This file is part of GNU Enterprise.
#
# GNU Enterprise is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2, or(at your option) any later version.
#
# GNU Enterprise is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
# PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public
# License along with program; see the file COPYING. If not,
# write to the Free Software Foundation, Inc., 59 Temple Place
# - Suite 330, Boston, MA 02111-1307, USA.
#
# Copyright 2000-2004 Free Software Foundation
#
"""
Information on this driver
"""

#
# Notes on this driver
#
name = _("PythonWin ODBC Driver")
url = "http://www.python.org/windows/win32/odbc.html"
doc = """
Description
-----------
PythonWin ODBC driver for Windows.

Support
-------
Supported Platforms:

  - MS Windows 98/NT/2000/XP (Installer available)


Connection Properties
----------------------
* service    -- This is the ODBC DSN= connection string for the database

Examples
--------
  [myconn]
  provider=odbc           # Use the ODBC adapter
  service=mydsn           # The DSN connection string of the database

Notes
-----
1. Since the underlying driver does not support introspection, GNUe cannot
   support ODBC introspection via this driver.
"""

==> gnue-common_0.5.14.orig.tar.gz: gnue-common-0.5.14/src/datasources/drivers/odbc/wodbc/Info.py <==
#
# This file is part of GNU Enterprise.
#
# GNU Enterprise is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2, or(at your option) any later version.
#
# GNU Enterprise is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
# PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public
# License along with program; see the file COPYING. If not,
# write to the Free Software Foundation, Inc., 59 Temple Place
# - Suite 330, Boston, MA 02111-1307, USA.
#
# Copyright 2000-2005 Free Software Foundation
#
"""
Information on this driver
"""

#
# Notes on this driver
#
name = _("PythonWin ODBC Driver")
url = "http://www.python.org/windows/win32/odbc.html"
doc = """
Description
-----------
PythonWin ODBC driver for Windows.

Support
-------
Supported Platforms:

  - MS Windows 98/NT/2000/XP (Installer available)


Connection Properties
----------------------
* service    -- This is the ODBC DSN= connection string for the database

Examples
--------
  [myconn]
  provider=odbc           # Use the ODBC adapter
  service=mydsn           # The DSN connection string of the database

Notes
-----
1. Since the underlying driver does not support introspection and schema
   creation, GNUe cannot support ODBC introspection and schema creation via
   this driver.

2. Other than that, the driver is fully functional with no known serious
   problems.
"""
